Crate geam_stdlib

Crate geam_stdlib 

Structs

Component
The statically composed provider component for the official Gleam standard library.
GleamStdlibProfile
The default profile for using only the official Gleam standard library providers.
GleamStdlibRunState
Caller-owned mutable state used by the official Gleam standard library.
GleamStdlibRunStateError
Failure to initialize standard-library run state from system entropy.
GleamStdlibStores
External value stores used by the official Gleam standard library providers.
IoOutput
One owned standard-library IO event.

Enums

IoStream
The standard stream selected by a Gleam IO operation.

Traits

GleamStdlibHostProfile
A host profile that exposes state and storage for the official Gleam standard library.
IoSink
A caller-owned destination for official Gleam standard-library IO events.

Functions

host_providers
Registers the Rust providers for the official Gleam standard library.