Skip to main contentCrate geam_stdlib
Source - Component
- The statically composed provider component for the official Gleam standard library.
- GleamStdlibProfile
- The default profile for using only the official Gleam standard library providers.
- GleamStdlibRunState
- Caller-owned mutable state used by the official Gleam standard library.
- GleamStdlibRunStateError
- Failure to initialize standard-library run state from system entropy.
- GleamStdlibStores
- External value stores used by the official Gleam standard library providers.
- IoOutput
- One owned standard-library IO event.
- IoStream
- The standard stream selected by a Gleam IO operation.
- GleamStdlibHostProfile
- A host profile that exposes state and storage for the official Gleam standard library.
- IoSink
- A caller-owned destination for official Gleam standard-library IO events.
- host_providers
- Registers the Rust providers for the official Gleam standard library.